# See: https://www.charset.org/utf-8
BACKSLASH = 92
QUOTE = 34
OPEN_SQUARE = 91
CLOSE_SQUARE = 93
OPEN_CURLY = 123
CLOSE_CURLY = 125
SPACE = 32
TAB = 9
NEWLINE = 10
COMMA = 44
